﻿using System;
using System.Windows.Forms;

namespace RCM {
    [Serializable]
    [DisplayName("Remote Desktop (RDP)")]
    public class RDP : IRecord {
        public Guid Id { get; set; }
        public string Title { get; set; }
        public Guid GroupId { get; set; }

        public string Host { get; set; }
        public string Username { get; set; }
        public string Password { get; set; }
        public string Notes { get; set; }
        [NonSerialized]
        private SimpleHostControl _control;
        [NonSerialized]
        private IAction[] _actions;

        public IAction[] GetActions() {
            if (_actions == null) {
                _actions = new IAction[] { new RDPAction(this), new SMBAction(this) };
            }
            return _actions;
        }

        public UserControl GetControl() {
            if (_control == null || _control.IsDisposed) {
                _control = new SimpleHostControl(Host, Username, Password, Notes);
            }
            return _control;
        }

        public void UpdateFromControl() {
            Host = _control.textBoxHostAddress.Text;
            Username = _control.textBoxUsername.Text;
            Password = _control.textBoxPassword.Text;
            Notes = _control.textBoxNotes.Text;
        }
    }
}
