﻿using System;
using System.Diagnostics;
using System.IO;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

namespace RCM {
    [DisplayName("Browse via SCP")]
    public class SCPAction : IAction {
        private SSH _ssh;
        private SSHConfig _config;

        public SCPAction(SSH ssh) {
            _ssh = ssh;
            _config = (SSHConfig)Config.ConfigSections[typeof(SSHConfig)];
        }

        public async void Run() {
            await Task.Run(() => {
                if (Environment.OSVersion.Platform == PlatformID.Unix) {
                    RunUnix();
                } else {
                    RunWin();
                }
            });
        }

        private void RunWin() {
            if (string.IsNullOrWhiteSpace(_config.WinSCPPath)) {
                MessageBox.Show("WinSCP path is not set", "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                return;
            }
            if (!File.Exists(_config.WinSCPPath)) {
                MessageBox.Show("WinSCP path does not exist", "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                return;
            }
            if ((_config.SSHKeys == null || _config.SSHKeys.Length == 0) && string.IsNullOrWhiteSpace(_ssh.Password)) {
                MessageBox.Show("No authentication method was set", "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                return;
            }
            if (_config.SSHKeys != null && _config.SSHKeys.Length != 0) {
                if (string.IsNullOrWhiteSpace(_config.PageantPath)) {
                    MessageBox.Show("Pageant path is not set", "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                    return;
                }
                if (!File.Exists(_config.PageantPath)) {
                    MessageBox.Show("Pageant path does not exist", "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                    return;
                }
            }

            StringBuilder scpParams = new StringBuilder();
            if (_config.SSHKeys != null && _config.SSHKeys.Length != 0) {
                StringBuilder pageantParams = new StringBuilder();
                foreach (string sshKey in _config.SSHKeys) {
                    pageantParams.AppendFormat("\"{0}\" ", sshKey);
                }
                Process.Start(_config.PageantPath, pageantParams.ToString());
            }
            scpParams.AppendFormat("sftp://{0}@{1}", _ssh.Username, _ssh.Host);
            if (!string.IsNullOrWhiteSpace(_ssh.Password)) {
                scpParams.AppendFormat(" \"/password={0}\"", _ssh.Password);
            }
            Process.Start(_config.WinSCPPath, scpParams.ToString());
        }

        private void RunUnix() {
            MessageBox.Show("This feature is not yet implemented", "Warning", MessageBoxButtons.OK, MessageBoxIcon.Warning);
            // TODO: Implement
        }
    }
}
