﻿using System;
using System.Diagnostics;
using System.IO;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

namespace RCM {
    [DisplayName("Start SSH")]
    public class SSHAction : IAction {
        private SSH _ssh;
        private SSHConfig _config;

        public SSHAction(SSH ssh) {
            _ssh = ssh;
            _config = (SSHConfig)Config.ConfigSections[typeof(SSHConfig)];
        }

        public async void Run() {
            await Task.Run(() => {
                if (Environment.OSVersion.Platform == PlatformID.Unix) {
                    RunUnix();
                } else {
                    RunWin();
                }
            });
        }

        private void RunWin() {
            if (string.IsNullOrWhiteSpace(_config.PuttyPath)) {
                MessageBox.Show("PuTTY path is not set", "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                return;
            }
            if (!File.Exists(_config.PuttyPath)) {
                MessageBox.Show("PuTTY path does not exist", "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                return;
            }
            if ((_config.SSHKeys == null || _config.SSHKeys.Length == 0) && string.IsNullOrWhiteSpace(_ssh.Password)) {
                MessageBox.Show("No authentication method was set", "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                return;
            }
            if (_config.SSHKeys != null && _config.SSHKeys.Length != 0) {
                if (string.IsNullOrWhiteSpace(_config.PageantPath)) {
                    MessageBox.Show("Pageant path is not set", "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                    return;
                }
                if (!File.Exists(_config.PageantPath)) {
                    MessageBox.Show("Pageant path does not exist", "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                    return;
                }
            }

            string[] host = _ssh.Host.Split(":".ToCharArray());
            StringBuilder puttyParams = new StringBuilder();
            if (_config.SSHKeys != null && _config.SSHKeys.Length != 0) {
                StringBuilder pageantParams = new StringBuilder();
                foreach (string sshKey in _config.SSHKeys) {
                    pageantParams.AppendFormat("\"{0}\" ", sshKey);
                }
                Process.Start(_config.PageantPath, pageantParams.ToString());
            }
            if (!string.IsNullOrWhiteSpace(_ssh.Password)) {
                puttyParams.AppendFormat("-pw {0} ", _ssh.Password);
            }
            if (host.Length > 1) {
                puttyParams.AppendFormat("-P {0} ", host[1]);
            }
            if (!string.IsNullOrWhiteSpace(_ssh.Username)) {
                puttyParams.AppendFormat("{0}@", _ssh.Username);
            }
            puttyParams.Append(host[0]);
            Process.Start(_config.PuttyPath, puttyParams.ToString());
        }

        private void RunUnix() {
            string[] host = _ssh.Host.Split(":".ToCharArray());
            StringBuilder sshParams = new StringBuilder("ssh ");
            if (host.Length > 1) {
                sshParams.AppendFormat("-p {0} ", host[1]);
            }
            if (!string.IsNullOrWhiteSpace(_ssh.Username)) {
                sshParams.AppendFormat("{0}@", _ssh.Username);
            }
            sshParams.Append(host[0]);

            string[] cmd = _config.LinuxSSHCommand.Replace("$SSH", sshParams.ToString()).Split(" ".ToCharArray(), 2);
            if (cmd.Length == 0) {
                MessageBox.Show("No SSH command was set", "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            } else if (cmd.Length == 1) {
                Process.Start(cmd[0]);
            } else {
                Process.Start(cmd[0], cmd[1]);
            }
        }
    }
}
